
![](https://raw.githubusercontent.com/epykure/epyk-ui/master/epyk/static/images/epyklogo_whole_big.png)

### First Version out now!

An easy to use Python Framework using JavaScript modules.

Presentation
================================
The target of epyk is to ensure the implementation of a coherent system using a minimum of layers.
With epyk the user stays in the Python layer to drive and optimize the data transformation.
This Framework also encourages the implementation of Micro services and cloud based architecture.

Compatibility
================================

epyk is compatible with the most common Web Python Frameworks (Flask and Django).
By default, the server package embeds a Flask app as it is easier to install and ready to use.

The Framework can be included within a Jupyter or JupyterLab project. But this will lead to some limitations - for example Ajax and Socket will not be available.

Coming Soon
================================

Please get in touch if there is any feature you feel Epyk-UI needs.
